@@ -1,5 +1,7 @@
 from simple_ddl_parser.utils import check_spec
 
+from simple_ddl_parser.utils import remove_par
+
 
 class HQL:
     def p_expression_location(self, p):
@@ -28,12 +30,8 @@ class HQL:
 
         p[0]["row_format"] = format
 
-    def p_assigment(self, p):
-        """assigment : ID ID ID"""
-        p_list = list(p)
-        p[0] = {p[1]: self.lexer.state.get(p_list[-1])}
 
-    def p_expression_with_serdie(self, p):
+    def p_expression_with_serde(self, p):
         """expr : expr WITH SERDEPROPERTIES LP assigment RP"""
         p[0] = p[1]
         p_list = list(p)
@@ -41,6 +39,34 @@ class HQL:
         row_format["properties"] = p_list[-2]
         p[0]["row_format"] = row_format
 
+    def p_expression_tblproperties(self, p):
+        """expr : expr TBLPROPERTIES multi_assigments"""
+        p[0] = p[1]
+        p_list = list(p)
+        p[0]["tblproperties"] = list(p)[-1]
+
+    def p_multi_assigments(self, p):
+        """multi_assigments : LP assigment
+         | multi_assigments RP
+         | multi_assigments COMMA assigment RP"""
+        p_list = remove_par(list(p))
+        p[0] = p_list[1]
+        p[0].update(p_list[-1])
+
+    def p_assigment(self, p):
+        """assigment : ID ID ID
+        |  STRING ID STRING
+        |  ID ID STRING
+        |  STRING ID ID
+        |  STRING ID"""
+        p_list = remove_par(list(p))
+        if 'state' in self.lexer.__dict__:
+            p[0] = {p[1]: self.lexer.state.get(p_list[-1])}
+        else:
+            if '=' in p_list[-1]:
+                p_list[-1] = p_list[-1].split('=')[-1]
+            p[0] = {p_list[1]: p_list[-1]}
+
     def p_expression_comment(self, p):
         """expr : expr COMMENT STRING"""
         p[0] = p[1]
@@ -78,7 +104,20 @@ class HQL:
         p[0]["stored_as"] = p_list[-1]
 
     def p_expression_partitioned_by_hql(self, p):
-        """expr : expr PARTITIONED BY LP pid_with_type RP"""
+        """expr : expr PARTITIONED BY pid_with_type """
         p[0] = p[1]
         p_list = list(p)
-        p[0]["partitioned_by"] = p_list[-2]
+        p[0]["partitioned_by"] = p_list[-1]
+    
+    def p_pid_with_type(self, p):
+        """pid_with_type :  LP column
+        | pid_with_type COMMA column
+        | pid_with_type RP
+        """
+        p_list = remove_par(list(p))
+        if not isinstance(p_list[1], list):
+            p[0] = [p_list[1]]
+        else:
+            p[0] = p_list[1]
+            if len(p_list) > 2:
+                p[0].append(p_list[-1])
